@@ -118,3 +118,8 @@ def format_string(text):
     pattern = re.compile('<[A-Za-z\\/].*?>')
     text = re.sub(pattern, '', text)
     return text
+
+
+def format_phone(phone):
+    phone = re.sub(u"([^0-9+])", "", phone)
+    return phone
